@@ -82,23 +82,23 @@ class KDEGAMESPRIVATE_EXPORT KChatBaseModel : public QAbstractListModel
 
 public:
   /** Default constructor */
-  KChatBaseModel(QObject *parent = 0);
+  explicit KChatBaseModel(QObject *parent = nullptr);
 
   /** Default destructor */
-  virtual ~KChatBaseModel();
+  ~KChatBaseModel() Q_DECL_OVERRIDE;
 
   /**
     * Reimplementation of the inherited method.
     * @return The current number of messages in the list
     */
-  virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
+  int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
 
   /**
     * Reimplementation of the inherited method.
     * @return The KChatBaseMessage at the given index as a QVariant
     */
-  virtual QVariant data(const QModelIndex &index, int role) const;
+  QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
 
   /**
    * Set the font that is used for the name part of a message. See also
@@ -146,7 +146,7 @@ public:
 
   /**
    * This font should be used for a message. layoutMessage sets the
-   * font of a message using KChatBaseItemDelegate::setMessageFont but if ypu
+   * font of a message using KChatBaseItemDelegate::setMessageFont but if you
    * replace layoutMessage with your own function you should use
    * messageFont() yourself.
    * @return The font that is used for a message
